% Aufgabe 2.6.3: Funktions-Plot
%    fncPlot( anfang, ende, diff )
%    anfang : Startpunkt, z.B. -5
%    ende : Endpunkt, z.B. +6
%    diff : Abstand der Stützstellen, z.B. 0.1
function  fncPlot( anfang, ende, diff )
  % 1. Berechnungspunkt: anfang
  akt = anfang;
  % 1. Element der Matrix
  n = 1;
 
  % Vektoren x und y berechnen, bis ende erreicht ist 
  while (akt <= ende)
    % x-Matrix von anfang bis ende  
    x(n) = akt;
    % y-Matrix = sin-Wert zu x
    y(n) = (x(n)*x(n)*x(n) + 5*x(n))*cos(3*x(n));
    
    % nächste Vektorkomponente wählen
    n = n +1;
    % akt. Berechnungspunkt, um diff weiter
    akt = akt + diff;
  end
 
  % Daten plotten
  plot(x,y,'r');
  % dazu Grid einschalten
  grid on; 
  
  title( 'Funktion: (x*x*x + 5*x)*cos(3*x)' );
  xlabel( 'x-Achse' );
  ylabel( 'y-Achse' );
end